@@ -199,6 +199,8 @@ main (gint argc, gchar *argv[])
   /* No restart */
   if (norestart)
     g_setenv ("LAUNCHER_NORESTART", "1", TRUE);
+  else
+    g_setenv ("LAUNCHER_NORESTART", "0", TRUE);
 
   /* Init() the main application */
   app = launcher_app_get_default ();
@@ -302,8 +304,26 @@ on_system_resume (LauncherConfig *config)
 }
 
 /*
- * What happens when the stage changes size 
+ * What happens when the stage changes size
+ * NOTE: Only send --no-restart if it's currently enabled, otherwise the
+ * launcher will not react when RESIZE>SUSPEND>RESUME
  */
+static void
+restart_launcher_for_resize ()
+{
+  LauncherCatbar *bar;
+  gchar *exec;
+  
+  bar = (LauncherCatbar *)launcher_catbar_get_default ();
+  exec = g_strdup_printf ("ume-launcher %s --last-category=%d",
+                          norestart ? "--no-restart" : " ",
+                          launcher_catbar_get_active_category (bar));
+  gdk_spawn_command_line_on_screen (gdk_screen_get_default (),
+                                    exec, NULL);
+  g_free (exec);
+  clutter_main_quit ();
+}
+
 static void    
 size_changed (GdkScreen    *screen,
               ClutterActor *app)
@@ -318,5 +338,5 @@ size_changed (GdkScreen    *screen,
     return;
 
   already_called = TRUE;
-  restart_launcher ();
+  restart_launcher_for_resize ();
 }
